@@ -1,4 +1,5 @@
 import os
+import logging
 
 from ._version import get_versions
 
@@ -11,5 +12,7 @@ entity_support = False
 IMG_DIRECTORY = os.path.join(os.path.dirname(__file__), "img")
 
 from .api import *
-from .utils.log import log
 from amulet.level.load import load_level, load_format
+
+# init a default logger
+logging.basicConfig(level=logging.INFO, format="%(levelname)s - %(message)s")
