@@ -17,6 +17,7 @@ import time
 import glob
 import shutil
 import json
+import logging
 
 import portalocker
 
@@ -55,6 +56,7 @@ from amulet.api import level as api_level
 from amulet.level.interfaces.chunk.anvil.base_anvil_interface import BaseAnvilInterface
 from .data_pack import DataPack, DataPackManager
 
+log = logging.getLogger(__name__)
 
 InternalDimension = str
 OVERWORLD = "minecraft:overworld"
@@ -161,7 +163,10 @@ class AnvilFormat(WorldFormatWrapper[VersionNumberInt]):
 
     @property
     def last_played(self) -> int:
-        return self.root_tag.compound.get_compound("Data").get_long("LastPlayed").py_int
+        return (
+            self.root_tag.compound.get_compound("Data").get_long("LastPlayed").py_int
+            // 1000
+        )
 
     @property
     def game_version_string(self) -> str:
@@ -226,12 +231,13 @@ class AnvilFormat(WorldFormatWrapper[VersionNumberInt]):
             self._dimension_name_map[dimension_name] = relative_dimension_path
             bounds = DefaultSelection
             if self.version >= 2709:  # This number might be smaller
-                dimension_tag = (
+                dimension_settings = (
                     self.root_tag.compound.get_compound("Data", CompoundTag())
                     .get_compound("WorldGenSettings", CompoundTag())
                     .get_compound("dimensions", CompoundTag())
-                    .get_compound(dimension_name, CompoundTag())["type"]
+                    .get_compound(dimension_name, CompoundTag())
                 )
+                dimension_tag = dimension_settings.get("type")
                 if isinstance(dimension_tag, StringTag):
                     # the settings are in the data pack
                     dimension_name = dimension_tag.py_str
@@ -290,12 +296,13 @@ class AnvilFormat(WorldFormatWrapper[VersionNumberInt]):
 
                 elif isinstance(dimension_tag, CompoundTag):
                     # the settings are here
-                    dimension_settings = dimension_tag
+                    dimension_compound_tag = dimension_tag
                     min_y = (
-                        dimension_settings.get_int("min_y", IntTag()).py_int // 16
+                        dimension_compound_tag.get_int("min_y", IntTag()).py_int // 16
                     ) * 16
                     height = (
-                        -dimension_settings.get_int("height", IntTag(256)).py_int // 16
+                        -dimension_compound_tag.get_int("height", IntTag(256)).py_int
+                        // 16
                     ) * -16
                     bounds = SelectionGroup(
                         SelectionBox(
@@ -303,6 +310,10 @@ class AnvilFormat(WorldFormatWrapper[VersionNumberInt]):
                             (30_000_000, min_y + height, 30_000_000),
                         )
                     )
+                else:
+                    log.error(
+                        f"Expected dimension_tag to be a StringTag or CompoundTag. Got {repr(dimension_tag)} for dimension {dimension_name}"
+                    )
 
             self._bounds[dimension_name] = bounds
 
@@ -400,7 +411,7 @@ class AnvilFormat(WorldFormatWrapper[VersionNumberInt]):
                 self._register_dimension(dir_name)
 
         for dimension_path in glob.glob(
-            os.path.join(self.path, "dimensions", "*", "*", "region")
+            os.path.join(glob.escape(self.path), "dimensions", "*", "*", "region")
         ):
             dimension_path_split = dimension_path.split(os.sep)
             dimension_name = f"{dimension_path_split[-3]}:{dimension_path_split[-2]}"
@@ -528,8 +539,6 @@ class AnvilFormat(WorldFormatWrapper[VersionNumberInt]):
     def _save(self):
         """Save the data back to the disk database"""
         os.makedirs(self.path, exist_ok=True)
-        for level in self._levels.values():
-            level.save()
         self.root_tag.save_to(os.path.join(self.path, "level.dat"))
         # TODO: save other world data
 
@@ -637,7 +646,9 @@ class AnvilFormat(WorldFormatWrapper[VersionNumberInt]):
         """
         Returns a generator of all player ids that are present in the level
         """
-        for f in glob.iglob(os.path.join(self.path, "playerdata", "*.dat")):
+        for f in glob.iglob(
+            os.path.join(glob.escape(self.path), "playerdata", "*.dat")
+        ):
             yield os.path.splitext(os.path.basename(f))[0]
         if self.has_player(LOCAL_PLAYER):
             yield LOCAL_PLAYER
@@ -734,4 +745,3 @@ if __name__ == "__main__":
     chunk_ = world.get_chunk_data(0, 0)
     print(chunk_)
     world.put_chunk_data(0, 0, chunk_)
-    world.save()
