@@ -1,11 +1,13 @@
 from __future__ import annotations
 
-from .anvil_1912 import (
-    Anvil1912Interface,
-)
+from .anvil_1912 import Anvil1912Interface as ParentInterface
 
 
-class Anvil1934Interface(Anvil1912Interface):
+class Anvil1934Interface(ParentInterface):
+    """
+    Made lighting optional
+    """
+
     def __init__(self):
         super().__init__()
         self._set_feature("light_optional", "true")
