@@ -1,6 +1,7 @@
 from __future__ import annotations
 
-from typing import Tuple, Dict, List, TYPE_CHECKING
+import logging
+from typing import Tuple, Dict, Iterator, TYPE_CHECKING
 
 import numpy
 from amulet_nbt import (
@@ -12,7 +13,7 @@ from amulet_nbt import (
     CompoundTag,
     ByteArrayTag,
     IntArrayTag,
-    BaseArrayType,
+    AbstractBaseArrayTag,
     NamedTag,
 )
 
@@ -20,8 +21,7 @@ import amulet
 from amulet.api.data_types import SubChunkNDArray, AnyNDArray, BlockCoordinates
 from amulet.utils import world_utils
 from amulet.api.wrapper import EntityIDType, EntityCoordType
-from amulet.api.chunk import Chunk, StatusFormats, EntityList
-from amulet.api.entity import Entity
+from amulet.api.chunk import Chunk, StatusFormats
 from .base_anvil_interface import (
     BaseAnvilInterface,
     ChunkDataType,
@@ -31,6 +31,8 @@ from .base_anvil_interface import (
 if TYPE_CHECKING:
     from amulet.api.chunk import Chunk
 
+log = logging.getLogger(__name__)
+
 
 class AnvilNAInterface(BaseAnvilInterface):
     Level: ChunkPathType = ("region", [("Level", CompoundTag)], CompoundTag)
@@ -218,8 +220,8 @@ class AnvilNAInterface(BaseAnvilInterface):
         self, chunk: Chunk, data: ChunkDataType, floor_cy: int, height_cy: int
     ):
         biomes = self.get_layer_obj(data, self.Biomes, pop_last=True)
-        if isinstance(biomes, BaseArrayType) and biomes.np_array.size == 256:
-            chunk.biomes = biomes.astype(numpy.uint32).reshape((16, 16))
+        if isinstance(biomes, AbstractBaseArrayTag) and biomes.np_array.size == 256:
+            chunk.biomes = biomes.np_array.astype(numpy.uint32).reshape((16, 16))
 
     def _decode_height(
         self, chunk: Chunk, data: ChunkDataType, floor_cy: int, height_cy: int
@@ -228,7 +230,7 @@ class AnvilNAInterface(BaseAnvilInterface):
         if isinstance(height, numpy.ndarray) and height.size == 256:
             chunk.misc["height_map256IA"] = height.reshape((16, 16))
 
-    def _iter_sections(self, data: ChunkDataType):
+    def _iter_sections(self, data: ChunkDataType) -> Iterator[Tuple[int, CompoundTag]]:
         sections: ListTag = self.get_layer_obj(data, self.Sections)
         for section in sections:
             yield section["Y"].py_int, section
@@ -242,12 +244,12 @@ class AnvilNAInterface(BaseAnvilInterface):
         for cy, section in self._iter_sections(data):
             block_tag = section.pop("Blocks", None)
             data_tag = section.pop("Data", None)
-            if not isinstance(block_tag, BaseArrayType) or not isinstance(
-                data_tag, BaseArrayType
+            if not isinstance(block_tag, AbstractBaseArrayTag) or not isinstance(
+                data_tag, AbstractBaseArrayTag
             ):
                 continue
-            section_blocks = numpy.frombuffer(block_tag, dtype=numpy.uint8)
-            section_data = numpy.frombuffer(data_tag, dtype=numpy.uint8)
+            section_blocks = numpy.asarray(block_tag, dtype=numpy.uint8)
+            section_data = numpy.asarray(data_tag, dtype=numpy.uint8)
             section_blocks = section_blocks.reshape((16, 16, 16))
             section_blocks = section_blocks.astype(numpy.uint16)
 
@@ -255,8 +257,8 @@ class AnvilNAInterface(BaseAnvilInterface):
             section_data = section_data.reshape((16, 16, 16))
 
             add_tag = section.pop("Add", None)
-            if isinstance(add_tag, BaseArrayType):
-                add_blocks = numpy.frombuffer(add_tag, dtype=numpy.uint8)
+            if isinstance(add_tag, AbstractBaseArrayTag):
+                add_blocks = numpy.asarray(add_tag, dtype=numpy.uint8)
                 add_blocks = world_utils.from_nibble_array(add_blocks)
                 add_blocks = add_blocks.reshape((16, 16, 16))
 
@@ -392,8 +394,9 @@ class AnvilNAInterface(BaseAnvilInterface):
         height_cy: int,
     ) -> Dict[int, CompoundTag]:
         """Get or create the section array populating all valid sections"""
-        sections = self.set_layer_obj(data, self.Sections, setdefault=True)
+        sections: ListTag = self.set_layer_obj(data, self.Sections, setdefault=True)
         section_map: Dict[int, CompoundTag] = {}
+        section: CompoundTag
         for section_index in range(len(sections) - 1, -1, -1):
             section = sections[section_index]
             cy = section.get("Y", None)
@@ -539,7 +542,7 @@ class AnvilNAInterface(BaseAnvilInterface):
                         )
                     )
                 except Exception:
-                    amulet.log.error(f"Could not serialise tick data {k}: {v}")
+                    log.error(f"Could not serialise tick data {k}: {v}")
         return ticks_out
 
     def _encode_block_ticks(
